@@ -1,7 +1,8 @@
 """
-1.0.1版新增level引數
+1.0.1新增level引數
+1.0.2給level預設值,使模組支援二種api(level可填可不填)
 """
-def printNext(theList,level):
+def printNext(theList,level=0):
     for eachN in theList:
         if isinstance(eachN,list):
             printNext(eachN,level+1)
